HPUX hpux_800[1m]






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)





 NAME
      hpux - HP-UX bootstrap and installation utility

 SYNOPSIS
      hpux [-o] [-F] [-m[p|s|x]] [-a[C|R|S|D] devicefile] [-fnumber]
      [-istring] [boot] [devicefile]
      hpux install [from devicefile] [to devicefile]
      hpux ls [devicefile]
      hpux set autofile devicefile string
      hpux show autofile [devicefile]
      hpux -v

    Obsolete:
      hpux copy devicefile devicefile

 DESCRIPTION
      hpux is the HP-UX-specific initial system loader (isl(1M)) utility for
      bootstrap and first-time installation.  It supports the following
      operations as indicated in the SYNOPSIS section above:

           boot           Loads an object file from an HP-UX file system or
                          raw device and transfers control to the loaded
                          image.

           install        Used during first time installation.  Attempts to
                          execute an install image from a properly formatted
                          installation device.

           ls             Lists the contents of HP-UX directories in a
                          format similar to ls(1).

           show autofile  Displays the contents of the autoexecute file.

           set autofile   Changes the contents of the autoexecute file to
                          that specified by string.

           -v             Display the release and version numbers of the
                          hpux utility.

           copy           Obsolete.  May not work on your system.  Copies
                          data between HP-UX files and/or raw devices.  This
                          operation is not recommended because it may damage
                          your file systems.

      hpux commands can be given interactively from the keyboard, or
      provided in an isl autoexecute file.

 NUMBERS
      hpux accepts numbers (i.e. numeric constants) in many of its options.
      Numbers follow the C language notation for decimal, octal, and
      hexadecimal constants.  A leading 0 (zero) implies octal and a leading



 Hewlett-Packard Company            - 1 -     HP-UX Release 9.0: August 1992






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)





      0x or 0X implies hexadecimal.  For example, 037, 0x1F, 0X1f, and 31
      all represent the same number: decimal 31.

 DEVICEFILES
      hpux boot, install, ls, and copy operations accept devicefile
      specifications, which have the following format:

           manager(w/x.y.z;n,s)filename

      They are called devicefiles because they are composed of a device name
      part and a file name part.  In the device part, manager(w/x.y.z;n,s),
      manager is the name of an HP 9000 Series 800 I/O System manager (i.e.
      device driver) such as disc0.  W/x.y.z is the physical hardware path
      to the device, identifying bus converters, slot numbers, and hardware
      addresses.  (Bus converter specifications are necessary only for
      models with bus converters such as the Model 850.  hpux only allows
      one level of bus converters).  N is the minor number which controls
      manager dependent functionality.  S is the file skip count.  For
      devices, this parameter describes how many files must be skipped (from
      the beginning of the tape) before the desired file can be accessed.
      It has a default value of 0, and is completely ignored for other
      devices.  The file name part, filename, is a standard HP-UX path name.
      Some hpux operations have defaults for particular components.  A
      devicefile specification containing a device part only specifies a raw
      device.  A devicefile specification containing a file name implies
      that the associated device part names a device containing an HP-UX
      file system.  The named file resides in that file system.  For
      example, a typical boot devicefile specification is
      disc0(2/4.0.0;0)hp-ux.

    Managers
      Currently, hpux supports the disc0, disc1, disc2, disc3, disc30,
      tape1, tape2, and lan1 managers.  Disc0 manages all CS/80 disks
      connected via HP-IB, including cartridge tape devices, and disc2
      manages all CS/80 disks connected via the HP27111 interface.  disc1
      manages all CS/80 disks connected via NIO HP-IB, including cartridge
      tape devices.  disc3 manages all disks connected via SCSI, including
      cartridge tape devices, and disc30 manages all auto-changer type disk
      devices.  lan1 manages remote boot through the HP28652A NIO based LAN
      interface.  Remote boot is currently supported on this card only and
      not on any CIO- based LAN card.  tape1 manages the HP7974, HP7978, and
      HP7980 tape drives via HP-IB, and tape2 manages tape drives via SCSI.

    Hardware Paths
      The hardware path in a devicefile specification is an arbitrary-length
      string of numbers, each suffixed by slash, (/), followed by an
      arbitrary-length string of numbers separated by periods (.).  Each
      number identifies a hardware component.  Hardware components suffixed
      by slashes indicate bus converters and may not be necessary on your
      machine.  A single number is the shortest path specification.  In
      w/x.y.z above, w would be the bus converter number, x would be the



 Hewlett-Packard Company            - 2 -     HP-UX Release 9.0: August 1992






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)





      MID-BUS module number, y would be the CIO slot number, and z would be
      the HP-IB address or HP27111 bus address.

    Minor Numbers
      The minor number, n, in a devicefile specification controls driver-
      dependent functionality.  The HP-UX System Administrator manuals
      describe specific minor number encodings for individual drivers.
      Since hpux manages its own logical units, it consequently ignores any
      logical unit information that may be specified in the minor number
      field of a devicefile.  For more information on the minor number
      formats for disc0, disc1, disc2, disc3, disc30, tape1, tape2, lan1,
      refer to the HP-UX System Administrator manuals for your system.

    Skip Counts
      The skip count, s, in a devicefile specification controls how many
      files must be skipped before the desired file is reached.  It is
      relative to the beginning of the tape, and is defined only for tape1
      and tape2 devices.  It is ignored for all others.  If not specified, 0
      is assumed.

    File Names
      File names are standard HP-UX path names.  No preceding slash (/) is
      necessary and specifying one will cause no problems.  File names are
      not root (i.e. /) relative.  For example, with disc0, disc1, disc2,
      and disc3, they are relative to the section specified in the minor
      number (in the device part) of the devicefile specification.

    Context-Dependent Files
      A file name can specify a context-dependent file (see cdf(4)).  This
      is done in either of two ways.  If the file name is of the form,

           filename+/context

      the operation is performed on context within the file specified by
      filename.  If the path name is of the form,

           filename

      and the file is a CDF, a default context is chosen for the operation
      (see DEFAULTS).

 DEFAULTS
      Default values chosen by hpux to complete a command are obtained
      through a sequence of steps.  First, any components of the command
      specified explicitly are used. If the command is not complete, hpux
      attempts to construct defaults from information maintained by pdc(1M).
      If sufficient information to complete the command is unavailable, the
      autoexecute and clusterconf files are searched.  On a search failure
      for any reason, any remaining unresolved components of the command are
      satisfied by hard-coded defaults.  The following sections detail how
      specific components will default.



 Hewlett-Packard Company            - 3 -     HP-UX Release 9.0: August 1992






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)





    Managers
      The choice for a default manager is determined exactly as stated
      above.  However, there is no hard-coded default.  If none can be
      chosen, this is an error.

    Hardware Paths
      When the hardware path element is not specified, hpux obtains a
      default for it from information maintained by pdc.  Like the default
      for the manager element, the hardware path element has no hard-coded
      default.

    Minor Numbers
      If the minor number element is not supplied, a default will be taken
      from the autoexecute file since pdc does not supply any minor number
      information.  Failing that, the hard-coded default of 0 is used.

    Skip Counts
      When the skip count is not specified, the hard-coded default of 0 is
      always used.  Other sources providing a default value for this element
      are ignored.

    File Names
      For the boot command, a devicefile specification without a file name
      element indicates that the boot device does not contain an HP-UX file
      system.  It is thus interpreted as a NULL file name instead of a
      missing file name.  And so, the file name is not defaulted.  A
      completely missing devicefile specification does imply a missing file
      name and will be defaulted as usual. Since pdc maintains no
      information about file names, either the autoexecute file contents or
      the hard-coded default of hp-ux is chosen.

      For the ls command, the default file name taken from the autoexecute
      file is ignored. The default value is always the hard-coded value, .
      (period).

      For the install command, only components of the from devicefile can be
      defaulted.

    Context-Dependent Files
      For the boot command, if the file is a CDF, the autoexecute file is
      searched for the default context.  Failing that, the /etc/clusterconf
      (see clusterconf(4)) file is searched for the node name which is then
      used as the context.  Finally, if all else fails, the hard-coded
      default, localroot, is chosen.

      For the ls command, the defaults supplied by the autoexecute and
      /etc/clusterconf files are ignored.  The hard-coded value, localroot,
      is also ignored.  Contents of a CDF can be displayed by specifying the
      file name with an appended +.





 Hewlett-Packard Company            - 4 -     HP-UX Release 9.0: August 1992






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)





 boot OPERATION
      The boot operation loads an object file from an HP-UX file system or
      raw device as specified by the optional devicefile.  It then transfers
      control to the loaded image.

      Any missing components in a specified devicefile are supplied with a
      default.  For example, a devicefile of vmunix.new would actually yield
      disc0(8.0.0;0)vmunix.new and a devicefile of (8.0.1)hp-ux, for booting
      from the disk at HP-IB address 1, would yield disc0(8.0.1;0)hp-ux.
      Regardless of how incomplete the specified devicefile may be, boot
      announces the complete devicefile specification used to find the
      object file.  Along with this information, boot gives the sizes of the
      TEXT, DATA, and BSS, segments and the entry offset of the loaded
      image, before transferring control to it.

      The boot operation accepts several options.  Their meanings are:

           -a[C|R|S|D] devicefile
                     This option takes a devicefile specification (see
                     DEVICEFILES) and passes it to the loaded image.  If
                     that image is an HP-UX kernel, the kernel will erase
                     its predefined I/O configuration, and configure in the
                     specified devicefile.  When the C, R, S, or D option is
                     specified, the kernel configures the device as the
                     console, root, swap, or dump device, respectively.
                     Note that -a can be repeated multiple times and that
                     its use implies the -o option.

           -fnumber  This option takes a number (see NUMBERS) and passes it
                     as the flags word to the loaded image.

           -istring  This option accepts a string that specifies the initial
                     run-level for init(1M).  Note that the run-level
                     specified will override any run-level specified in an
                     initdefault entry in /etc/inittab (see inittab(4)).

           -o        This option passes the console and boot device paths
                     and drivers to the loaded image.  If that image is an
                     HP-UX kernel, the kernel will erase its predefined I/O
                     configuration, and replace its console and root device
                     paths and drivers with those passed from boot.  In
                     addition, the primary swap device is also placed on the
                     boot device.  This is useful for forcing a boot if the
                     kernel has an incorrect I/O configuration.

           -m[p|s|x] If the loaded image is an HP-UX kernel, this option
                     controls the kernel's choice of which section in a
                     mirrored root should be ONLINE.  Without this option,
                     the kernel chooses the section that was ONLINE when the
                     system went down, or the primary section if both
                     sections were ONLINE.  -m alone causes the kernel to



 Hewlett-Packard Company            - 5 -     HP-UX Release 9.0: August 1992






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)





                     use the previously OFFLINE section, or the secondary
                     section if both sections were previously ONLINE.  -mp
                     and -ms specify the primary and secondary sections,
                     respectively.

                     If one of the mirrored disks is inaccessible, the
                     kernel on rare occasions cannot tell if the accessible
                     disk was ONLINE when the system went down.  Normally,
                     it prints a message asking for help, and halts, since
                     an incorrect choice can cause data corruption.  With
                     -mx, the kernel always uses the accessible disk,
                     regardless of the possibility of corruption; it is
                     useful for the AUTO file on systems where availability
                     is more important than reliability (for example, a
                     machine controller, or a system that provides access to
                     a read-only database of which there are other copies).

           -F        This option is for use with SWITCHOVER/UX software,
                     which is not in the HP-UX core.  It tells the kernel to
                     ignore any locks on the boot disk, and should only be
                     used when it is known that the processor with the lock
                     is no longer running. Without this option, if a disk is
                     locked by another processor, the kernel refuses to boot
                     from it, to avoid the corruption that would result if
                     the other processor were still using the disk.

           boot currently places some minor restrictions on object files it
           can load.  It accepts only the HP-UX magic numbers SHAREMAGIC
           (0410) and DEMANDMAGIC (0413) (see magic(4)).  The object file
           must contain an Auxiliary Header of the HPUX_AUX_ID type and it
           must be the first Auxiliary Header (see a.out(4)).

 install OPERATION
      The install operation is used during first-time installation to load
      and execute an install image from a properly formatted installation
      device.  The install operation is automatically translated to a boot
      operation from a devicefile based on the model of your system.  The
      path to the install source device is usually the same as the one
      specified to pdc but may be selected by the from option.

 set autofile OPERATION
      The set autofile operation overwrites the contents of the autoexecute
      file, autofile, with the string specified (see autoexecute in EXAMPLES
      section).

 show autofile OPERATION
      The show autofile operation prints the contents of the autoexecute
      file, autofile , on the display (see autoexecute in EXAMPLES section).

 copy OPERATION
      The copy operation is obsolete and should not be used.  It was



 Hewlett-Packard Company            - 6 -     HP-UX Release 9.0: August 1992






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)




      originally used during first-time installation to copy installation
      images from one device to another. Using this operation may damage
      your file system.

 ls OPERATION
      The ls operation lists the contents of the HP-UX directory specified
      by the optional devicefile.  The output is similar to that of the ls
      -alFH command, except that the owner, group, and date information is
      not printed.

      The default devicefile for ls is generated in the same way as the
      devicefile for boot.  However, the default file name is ``.''.

 EXAMPLES
      Before going over specific examples of the various options and
      operations of hpux, here is an outline of the steps taken in the
      automatic boot process.  Although the hardware configuration and boot
      paths shown are for a single Series 800 machine, the user interfaces
      are consistent across all models.  When the system RESET button is
      depressed, pdc executes self-test, and assuming the hardware passes,
      pdc announces itself, issues a BELL, and gives the user 10 seconds to
      override the autoboot sequence, by entering any character.  The
      following is typically displayed on the console.

           Processor Dependent Code (PDC) revision  2

           Console path = 8.1.0.0.0.0.0
           Primary boot path = 8.0.0.0.0.0.0
           Alternate boot path = 8.2.3.0.0.0.0

           Autoboot from primary boot path enabled.  To override, press any
           key within 10 seconds.

      If no character is entered within 10 seconds, pdc commences the
      autoboot sequence by loading isl and transferring control to it.
      Because an autoboot sequence is occurring, isl merely announces
      itself, finds and executes the autoexecute file which, on an HP-UX
      system, requests that hpux be run with appropriate arguments.  The
      following is displayed on the console.

           10 seconds expired.

           Booting.

           Console IO Dependent Code (IODC) revision 1
           Boot IO Dependent Code (IODC) revision 1

           Booted.

           ISL Revision 2634   August, 1986




 Hewlett-Packard Company            - 7 -     HP-UX Release 9.0: August 1992






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)





           ISL booting  hpux

      Next hpux announces the operation it is performing, in this case boot,
      the devicefile from which the load image comes, and the TEXT size,
      DATA size, BSS size, and start address of the load image.  The
      following is displayed before control is passed to the image.

           Boot
           : disc0(8.0.0;0x0)hp-ux
           966616+397312+409688 start 0x6c50

      Lastly, the loaded image, in this case an HP-UX operating system
      kernel, starts by giving numerous configuration and status messages.
      The system in the following example eventually comes to init run-level
      2 for multi-user mode of operation.


           Beginning I/O System Configuration.
           cio_ca0 address = 8
              hpib0 address = 0
                 disc0 lu = 0 address = 0
                 disc0 lu = 1 address = 1
                 disc0 lu = 2 address = 2
                 disc0 lu = 3 address = 3
              mux0 lu = 0 address = 1
               .
               .
           More deleted for brevity
               .
               .
           graph0 lu 0 address 12
           I/O System Configuration complete.
           Configure called
           @(#)9245XA HP-UX (sys.A.B1.10/S800) #1: Wed Dec 10 17:24:28 PST 1986
           real mem = 8386560
           lockable mem = 3297280
           avail mem = 5197824
           using 204 buffers containing 837632 bytes of memory

      In order to use the operations and options of hpux, isl must be
      brought up in interactive mode.  To do this simply enter a character
      during the 10-second interval allowed by pdc(1M).  pdc then asks if
      the primary boot path is acceptable.  Answering yes (Y) is usually
      appropriate.  pdc then loads isl and isl interactively prompts for
      commands.  The following is displayed.

           Boot from primary boot path (Y or N)?> Y

           Booting.





 Hewlett-Packard Company            - 8 -     HP-UX Release 9.0: August 1992






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)





           Console IO Dependent Code (IODC) revision 1
           Boot IO Dependent Code (IODC) revision 1

           Booted.

           ISL Revision 2634  August, 1986

           ISL>

      Although all the operations and options of hpux can be used from isl
      interactively, they can also be executed from an autoexecute file.  In
      the examples below, all user input is in boldface type.

    Default Boot
           ISL> hpux

           Boot
           : disc0(8.0.0;0x4)hp-ux
           966616+397312+409688 start 0x6c50

      Entering hpux initiates the default boot sequence.  The boot path read
      from pdc is 8.0.0, the manager associated with the device at that path
      is disc0, the minor number, in this case derived from the autoexecute
      file, is 4 specifying section 4 of the disk, and the object file name
      is hp-ux.

    Booting Another Kernel
           ISL> hpux vmunix.new

           Boot
           : disc0(8.0.0;0x0)vmunix.new
           966616+397312+409688 start 0x6c50

      Here hpux initiates a boot operation where the name of the object file
      is vmunix.new.

    Booting from Another Section
           ISL> hpux (;3)sys.azure/S800/vmunix

           Boot
           : disc0(8.0.0;0x3)sys.azure/S800/vmunix
           966616+397312+409688 start 0x6c50

      In this example, a kernel is booted from another section of the root
      disk.  For example, let's say that kernel development takes place
      under /mnt/azure/root.port which happens to reside in its own section,
      section 3 of the root (i.e. default boot) disk.  By specifying a minor
      number of 3, in the above example, the object file
      sys.azure/S800/vmunix is loaded from /mnt/azure/root.port.





 Hewlett-Packard Company            - 9 -     HP-UX Release 9.0: August 1992






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)





    Booting from Cartridge Tape
           ISL> hpux (;4194336)hp-ux

           Boot
           : disc0(8.0.0;0x400020)hp-ux
           966616+397312+409688 start 0x6c50

      In this example, the default boot device is an HP7914 disk with a
      cartridge tape at unit 1.  The minor number has the cartridge tape
      flag set and specifies unit 1, section 0 of the device.  Although the
      minor number was entered in decimal format, the hexadecimal form would
      be accepted.  Since a file name is specified, it is assumed that
      section 0 contains a file system.

    Booting from Another Disk
           ISL> hpux (8.0.1)hp-ux

           Boot
           : disc0(8.0.1;0x0)hp-ux
           966616+397312+409688 start 0x6c50

      In this example, only the hardware path and file name are specified.
      All other values are boot defaults.  The object file comes from the
      file system in section 0 of the disk, at HP-IB address 1.

    Booting from LAN
           ISL> hpux lan1(32)hp-ux

           Boot
           : lan1(32;0x0)hp-ux
           966616+397312+409688 start 0x6c50

      This example shows how to boot a cluster client from the LAN. Though
      this example specifies a devicefile, using default boot, shown in a
      previous example, is also possible. For a boot operation other than
      default boot, the file name must be specified and be no more than 11
      characters in length. Booting to isl from a local disk and then
      requesting an image to be loaded from the LAN is NOT supported.

    Booting from a Raw Device
           ISL> hpux tape1(8.2.3;0xa0000,1)

           Boot
           : tape1(8.2.3;0xa0000,1)
           rewinding tape1(8.2.3;0xa0000,1) ... done
           skipping 1 file ... done
           966616+397312+409688 start 0x6c50

      This example shows booting from a raw device (i.e. no file system is
      on the device).  Note that no file name is specified in the
      devicefile.  The device is an HP 7974 tape drive and therefore tape1



 Hewlett-Packard Company           - 10 -     HP-UX Release 9.0: August 1992






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)





      is the manager used.  The tape drive is at CIO slot 2, HP-IB address
      3.  The first file on the tape will be skipped.  The minor number
      specifies a tape density of 1600 BPI and no rewind on close.  Note
      that, depending on the minor number, tape1 requires the tape be
      written with 512 or 1024 byte blocks.

    Booting to Single User Mode
           ISL> hpux -is

           Boot
           : disc0(8.0.0;0x0)hp-ux
           966616+397312+409688 start 0x6c50

           Kernel Startup Messages Omitted

           INIT: Overriding default level with level 's'

           INIT: SINGLE USER MODE
           WARNING:  YOU ARE SUPERUSER !!

           #

      In this example, the -i option is used to make the system come up in
      run-level s, for single user mode of operation.

    Booting with a Modified I/O Configuration
           ISL> hpux -aC mux0(8.1) -a tape1(8.2.0)

           Boot
           : disc0(8.0.0;0x0)hp-ux
           : Adding mux0(8.1;0x0)...
           : Adding tape1(8.2.0;0x0)...
           966616+397312+409688 start 0x6c50
           Beginning I/O System Configuration.
           cio_ca0 address = 8
              hpib0 address = 0
                 disc0 lu = 0 address = 0
              mux0 lu = 0 address = 1
              hpib0 address = 2
                 tape1 lu = 0 address = 0
           I/O System Configuration complete.

                Additional Kernel Startup Messages Omitted

      Here a tape driver is configured in at CIO slot 2, HP-IB address 0.
      Regardless of what was present in the kernel's original I/O
      configuration, the driver tape1 is now configured at that hardware
      path.  Similarly, mux0 is configured in at CIO slot 1 which is to be
      the console.  The only other devices configured are the console and
      root device, which boot derived from pdc .




 Hewlett-Packard Company           - 11 -     HP-UX Release 9.0: August 1992






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)





    First-Time Installation
           ISL> hpux install to disc0(8.0.0)

           Boot
           : tape1(8.2.3;0xa0000,1)
           : Adding disc0(8.0.0;0x0)...
           rewinding tape1(8.2.3;0xa0000,1) ... done
           skipping 1 file ... done
           966616+397312+409688 start 0x6c50

      This is an example of the install operation on a model 840.  In this
      example, pdc was instructed to boot from the boot path, "8.2.3".  hpux
      translated the install operation to a boot operation from this boot
      path using defaults characteristic of the model 840.  As a general
      rule, smaller systems (for example, model 815) default to installing
      from cartridge tape while larger systems (such as, model 850) default
      to reel tape.

      In this case, the optional to argument is used to force an
      installation to the HP-IB disk at "8.0.0".  hpux translates this
      option to an equivalent -a construct, which is necessary for
      installation. Though not shown by this example, the source
      installation device could have been changed by specifying the from
      devicefile argument. Any missing components of the devicefile
      associated with the from argument will be defaulted. However, those
      associated with the to argument will not.  The command in this example
      is functionally equivalent to the following command on a model 840.

           ISL> hpux -a disc0(8.0.0) tape1(8.2.3;0xa0000,1)

      Note: Due to variety of tasks being performed and the slow nature of
      tape based boot devices, this operation my take a good deal of time
      before announcing completion. Forward progress can be monitored by
      watching the tape or seven segment display on your machine.

    Displaying the autoexecute file
           ISL> hpux show autofile
           Show autofile
           : AUTO file contains (hpux -i2)

      In this example, show autofile is used to print the contents of the
      autoexecute file residing in the boot area, section 6, on the device
      from which hpux was booted. Optionally, a devicefile may be specified
      in order to read the autoexecute file from the boot area of some other
      boot device.

    Changing the autoexecute file
           ISL> hpux set autofile (;6) "hpux (;4)hp-ux.std"
           Set autofile
           : AUTO file now contains "hpux (;4)hp-ux.std"




 Hewlett-Packard Company           - 12 -     HP-UX Release 9.0: August 1992






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)





      This example shows how to change the contents of the autoexecute file.
      Once done, the system may be reset and the new command will be used
      during any unattended boot.

    Listing Directory Contents
           ISL> hpux ls

           Ls : disc0(8.0.0;0x4).  tab (#) ; c0 c0 c0 c0 c0 c0 c0 c0 c0 c n
           n l .  d#r#w#x#r#-#x#r#-#x#9#2048 ./ d#r#w#x#r#-#x#r#-#x#6#2048
           ../ d#r#w#x#r#-#x#r#-#x#2#4096 lost+found/
           -#r#w#-#r#w#-#r#-#-#1#746 .profile d#r#w#x#r#w#x#r#-#x#2#1024
           bin/ d#r#w#x#r#-#x#r#-#x#12#1024 dev/ d#r#w#x#r#w#x#r#-#x#5#1024
           etc/ d#r#w#x#r#w#x#r#w#x#2#64 tmp/ d#r#w#x#r#w#x#r#-#x#3#1024
           usr/ H#r#w#x#r#w#x#r#-#x#3#1024 foo+ -#r#w#x#r#-#x#r#-#x#1#884736
           hp-ux* -#r#w#x#r#-#x#r#-#x#1#884736 SYSBCKUP*
           -#r#w#x#r#-#x#r#-#x#1#1032192 hp-ux.test*
      The contents of the root directory (/)ontheroot The format shows the
      file protections, number of links, and size in bytes for each file in
      the directory.  There are three available kernels to boot: hp-ux,
      hp-ux.test, and SYSBCKUP.  Listing the files of a cluster server from
      a cluster client is not supported. Listing files within a CDF may be
      done by appending a ''+'' to the CDF file name. For example, ISL> hpux
      ls foo+ will list the contents of the foo CDF.

    Getting the Version
      ISL> hpux -v

      Release: 1.1
      Release Version:
      @(#)9245XA HP-UX (sys.A.B1.10/HPUXBOOT) #1: Wed Dec 10 17:24:28 PST 1986

      The -v option is used to get the version numbers of hpux.

 DIAGNOSTICS
      In the instance of an error hpux prints diagnostic messages which
      indicate the cause of the error.  These messages may be grouped
      General, Boot, Copy, Configuration, and System Call.  A description of
      the System Call error messages may be found in errno(2).  The
      remaining messages are described below.

    General
      bad minor number in devicefile spec
           The minor number in the devicefile specification is illegal.

      bad path in devicefile spec
           The hardware path in the devicefile specification is illegal.

      command too complex for parsing
           The command line contains too many arguments.





 Hewlett-Packard Company           - 13 -     HP-UX Release 9.0: August 1992






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)





      no path in devicefile spec
           The devicefile specification does not contain a hardware path
           component and must.

      panic (in hpuxboot): (display==number, flags==number) string
           A severe internal hpux error has occurred.  Report to your
           nearest HP Field Representative.

    Boot
      bad magic
           The specified object file does not have a legal magic number.

      bad number in flags spec
           The flags specification in the -f option is illegal.

      booting from raw character device
           In booting from a raw device, the manager specified only has a
           character interface.  This may cause problems if the block size
           is incorrect.

      Isl not present, please hit system RESET button to continue
           An unsuccessful boot operation has overlaid isl in memory.  It is
           impossible to return control to isl.

      short read
           The specified object file is internally inconsistent, it is not
           long enough.

      would overlay
           Loading the specified object file would overlay hpux.

    Copy
      cannot open destination device/file
           The destination device or file could not be opened for writing.

      cannot open source device/file
           The source device or file could not be opened for reading.

      fchmod failure (warning only)
           The access mode of the destination file could not be changed.

      fchown failure (warning only)
           The owner and/or group of the destination file could not be
           changed.

      fstat failure (warning only)
           One or more of the owner, group, or mode of the source file could
           not be determined.  The default values of owner and group are 0
           and 0.  The default mode is 0777.





 Hewlett-Packard Company           - 14 -     HP-UX Release 9.0: August 1992






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)




      read failure
           An error was encountered reading from the source device or file.

      umount failure on destination device
           The destination device could not be dismounted.  Its file system
           may have been damaged as a result.  fsck should be run before
           mounting the file system.

      umount failure on source device
           The source device could not be dismounted.  Since it was mounted
           read-only, the integrity of its file system is not at risk.

      write failure
           An error was encountered writing to the destination device or
           file.

    Configuration
      cannot add path, error number
           An unknown error has occurred in adding the hardware path to the
           I/O tree.  The internal error number is given.  Contact your HP
           Field Representative.

      driver does not exist
           The manager specified is not configured into hpux.

      driver is not a logical device manager
           The manager name given is not that of a logical device manager
           and cannot be used for direct I/O operations.

      error rewinding device
           An error was encountered attempting to rewind a device.

      error skipping file
           An error was encountered attempting to forward-space a tape
           device.

      negative skip count
           The skip count, if specified, must be greater than or equal to
           zero.

      no major number
           The specified manager has no entry in the block or character
           device switch tables.

      path incompatible with another path
           Multiple incompatible hardware paths have been specified.

      path long
           The hardware path specified contains too many components for the
           specified manager.




 Hewlett-Packard Company           - 15 -     HP-UX Release 9.0: August 1992






 hpux_800(1M)             Series 800 Implementation             hpux_800(1M)





      path short
           The hardware path specified contains too few components for the
           specified manager.

      table full
           Too many devices have been specified to hpux.

 SEE ALSO
      boot(1M), fsck(1M), init(1M), isl(1M), pdc(1M), errno(2), a.out(4),
      inittab(4), magic(4).












































 Hewlett-Packard Company           - 16 -     HP-UX Release 9.0: August 1992